==> kibana-7.9.1.tgz: kibana/src/plugins/vis_type_timeseries/server/lib/vis_data/request_processors/table/filter_ratios.js <==
"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ratios = ratios;

var _bucket_transform = require("../../helpers/bucket_transform");

var _helpers = require("../../helpers");

var _calculate_agg_root = require("./calculate_agg_root");

/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
const filter = metric => metric.type === 'filter_ratio';

function ratios(req, panel) {
  return next => doc => {
    panel.series.forEach(column => {
      const aggRoot = (0, _calculate_agg_root.calculateAggRoot)(doc, column);

      if (column.metrics.some(filter)) {
        column.metrics.filter(filter).forEach(metric => {
          (0, _helpers.overwrite)(doc, `${aggRoot}.timeseries.aggs.${metric.id}-numerator.filter`, {
            query_string: {
              query: metric.numerator || '*',
              analyze_wildcard: true
            }
          });
          (0, _helpers.overwrite)(doc, `${aggRoot}.timeseries.aggs.${metric.id}-denominator.filter`, {
            query_string: {
              query: metric.denominator || '*',
              analyze_wildcard: true
            }
          });
          let numeratorPath = `${metric.id}-numerator>_count`;
          let denominatorPath = `${metric.id}-denominator>_count`;

          if (metric.metric_agg !== 'count' && _bucket_transform.bucketTransform[metric.metric_agg]) {
            const aggBody = {
              metric: _bucket_transform.bucketTransform[metric.metric_agg]({
                type: metric.metric_agg,
                field: metric.field
              })
            };
            (0, _helpers.overwrite)(doc, `${aggRoot}.timeseries.aggs.${metric.id}-numerator.aggs`, aggBody);
            (0, _helpers.overwrite)(doc, `${aggBody}.timeseries.aggs.${metric.id}-denominator.aggs`, aggBody);
            numeratorPath = `${metric.id}-numerator>metric`;
            denominatorPath = `${metric.id}-denominator>metric`;
          }

          (0, _helpers.overwrite)(doc, `${aggRoot}.timeseries.aggs.${metric.id}`, {
            bucket_script: {
              buckets_path: {
                numerator: numeratorPath,
                denominator: denominatorPath
              },
              script: 'params.numerator != null && params.denominator != null && params.denominator > 0 ? params.numerator / params.denominator : 0'
            }
          });
        });
      }
    });
    return next(doc);
  };
}

==> kibana-7.10.0.tgz: kibana/src/plugins/vis_type_timeseries/server/lib/vis_data/request_processors/table/filter_ratios.js <==
"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ratios = ratios;

var _server = require("../../../../../../data/server");

var _bucket_transform = require("../../helpers/bucket_transform");

var _helpers = require("../../helpers");

var _calculate_agg_root = require("./calculate_agg_root");

/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
const filter = metric => metric.type === 'filter_ratio';

function ratios(req, panel, esQueryConfig, indexPatternObject) {
  return next => doc => {
    panel.series.forEach(column => {
      const aggRoot = (0, _calculate_agg_root.calculateAggRoot)(doc, column);

      if (column.metrics.some(filter)) {
        column.metrics.filter(filter).forEach(metric => {
          (0, _helpers.overwrite)(doc, `${aggRoot}.timeseries.aggs.${metric.id}-numerator.filter`, _server.esQuery.buildEsQuery(indexPatternObject, metric.numerator, [], esQueryConfig));
          (0, _helpers.overwrite)(doc, `${aggRoot}.timeseries.aggs.${metric.id}-denominator.filter`, _server.esQuery.buildEsQuery(indexPatternObject, metric.denominator, [], esQueryConfig));
          let numeratorPath = `${metric.id}-numerator>_count`;
          let denominatorPath = `${metric.id}-denominator>_count`;

          if (metric.metric_agg !== 'count' && _bucket_transform.bucketTransform[metric.metric_agg]) {
            const aggBody = {
              metric: _bucket_transform.bucketTransform[metric.metric_agg]({
                type: metric.metric_agg,
                field: metric.field
              })
            };
            (0, _helpers.overwrite)(doc, `${aggRoot}.timeseries.aggs.${metric.id}-numerator.aggs`, aggBody);
            (0, _helpers.overwrite)(doc, `${aggRoot}.timeseries.aggs.${metric.id}-denominator.aggs`, aggBody);
            numeratorPath = `${metric.id}-numerator>metric`;
            denominatorPath = `${metric.id}-denominator>metric`;
          }

          (0, _helpers.overwrite)(doc, `${aggRoot}.timeseries.aggs.${metric.id}`, {
            bucket_script: {
              buckets_path: {
                numerator: numeratorPath,
                denominator: denominatorPath
              },
              script: 'params.numerator != null && params.denominator != null && params.denominator > 0 ? params.numerator / params.denominator : 0'
            }
          });
        });
      }
    });
    return next(doc);
  };
}
